elephant.change\_point\_detection.multiple\_filter\_test
========================================================

.. currentmodule:: elephant.change_point_detection

.. autofunction:: multiple_filter_test